# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [v0.2.3] - 2025-03-15
### New Features
- [`d7799f1`](https://github.com/HydroRoll-Team/conventional_role_play/commit/d7799f1ff7fca7525fd09c2e51f366be1d0886b5) - simple parser rules load and log processing *(commit by [@pineoncellar](https://github.com/pineoncellar))*
- [`ee15a8b`](https://github.com/HydroRoll-Team/conventional_role_play/commit/ee15a8b3174048f1c9f7f53a51d1e5b7a2410054) - :page_facing_up: Add sample rule and log files *(commit by [@pineoncellar](https://github.com/pineoncellar))*

### Bug Fixes
- [`5c5b871`](https://github.com/HydroRoll-Team/conventional_role_play/commit/5c5b8713e90642a767c67eb8da7c9a40e5ca6859) - update documentation URL in Cargo.toml *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*


## [v0.2.2] - 2025-03-14
### Chores
- [`6d3a6d8`](https://github.com/HydroRoll-Team/conventional_role_play/commit/6d3a6d851d88e572e2125932febfb9844064a7d1) - replace README.rst with README.md and update pyproject.toml to reference new README format *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`1ddf2a5`](https://github.com/HydroRoll-Team/conventional_role_play/commit/1ddf2a5202e065a5df18dfa58a88faa5784a3f8c) - bump version to 0.2.2 and update version retrieval method in __init__.py *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*


## [v0.2.1] - 2025-03-14
### Chores
- [`00e130b`](https://github.com/HydroRoll-Team/conventional_role_play/commit/00e130b06051a7d250d2a0a9b901d46cbd9eb756) - update CI workflow to use Python 3.9 and add interpreter finding option *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`fb5b1fb`](https://github.com/HydroRoll-Team/conventional_role_play/commit/fb5b1fbba51d68619d64f53e68164cc7a7741370) - update CI workflow to consistently use Python 3.9 and remove unnecessary interpreter arguments *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`a10578c`](https://github.com/HydroRoll-Team/conventional_role_play/commit/a10578cfd63151739b36f9cc5ba81a4c0eda05ec) - bump version to 0.2.1 in Cargo.toml and __init__.py *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`9b696f0`](https://github.com/HydroRoll-Team/conventional_role_play/commit/9b696f003a2b7da575ea086c6ddc0c579a13f46b) - rename project to conventionalrp and update metadata in Cargo.toml and pyproject.toml *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*

[v0.2.1]: https://github.com/HydroRoll-Team/conventional_role_play/compare/v0.2.0...v0.2.1
[v0.2.2]: https://github.com/HydroRoll-Team/conventional_role_play/compare/v0.2.1...v0.2.2
[v0.2.3]: https://github.com/HydroRoll-Team/conventional_role_play/compare/v0.2.2...v0.2.3
